==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/trading_card/TradingCardManager.java <==
package cc.thonly.reverie_dreams.world.trading_card;

import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import it.unimi.dsi.fastutil.objects.ObjectArrayList;
import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1799;
import net.minecraft.class_3222;
import java.util.List;
import java.util.stream.Stream;

@Getter
public class TradingCardManager {
    public static final Codec<Entry> CODEC = Codec.unit(Entry::new);
    private final class_3222 player;
    private final Entry entry;

    private TradingCardManager() {
        this(null);
    }

    public TradingCardManager(class_3222 player) {
        this.player = player;
        this.entry = new Entry();
    }

    public void read(class_11368 view) {

    }

    public void write(class_11372 view) {

    }

    @Getter
    public static class Entry {
        public static Codec<Entry> EMPTY = Codec.unit(Entry::new);
        public static Codec<Entry> CODEC = RecordCodecBuilder.create(instance -> instance.group(
                ItemStackWrapper.CODEC.listOf().fieldOf("list").forGetter(Entry::getList)
        ).apply(instance, Entry::new));
        private List<ItemStackWrapper> list = new ObjectArrayList<>();

        public Entry() {

        }

        public Entry(List<ItemStackWrapper> list) {
            this.list = new ObjectArrayList<>(list);
        }

        public void add(class_1799 itemStack) {

        }

        public Stream<ItemStackWrapper> stream() {
            return this.list.stream();
        }

    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/trading_card/TradingCardManager.java <==
package cc.thonly.reverie_dreams.world.trading_card;

import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import it.unimi.dsi.fastutil.objects.ObjectArrayList;
import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1799;
import net.minecraft.class_3222;
import java.util.List;
import java.util.stream.Stream;

@Getter
public class TradingCardManager {
    public static final Codec<Entries> CODEC = Codec.unit(Entries::new);
    private final class_3222 player;
    private final Entries entries;

    private TradingCardManager() {
        this(null);
    }

    public TradingCardManager(class_3222 player) {
        this.player = player;
        this.entries = new Entries();
    }

    public void read(class_11368 view) {

    }

    public void write(class_11372 view) {

    }

    @Getter
    public static class Entries {
        public static Codec<Entries> EMPTY = Codec.unit(Entries::new);
        public static Codec<Entries> CODEC = RecordCodecBuilder.create(instance -> instance.group(
                ItemStackWrapper.CODEC.listOf().fieldOf("list").forGetter(Entries::getList)
        ).apply(instance, Entries::new));
        private List<ItemStackWrapper> list = new ObjectArrayList<>();

        public Entries() {

        }

        public Entries(List<ItemStackWrapper> list) {
            this.list = new ObjectArrayList<>(list);
        }

        public void add(class_1799 itemStack) {

        }

        public Stream<ItemStackWrapper> stream() {
            return this.list.stream();
        }

    }
}
